/**
 * Creating a new compound view by extending LinearLayout.
 * In this example the layout itself is defined as an external
 * resource {@link clearable_edit_text_view} which is inflated
 * within the constructor.
 */

package sample.com;


import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.nio.CharBuffer;
import java.util.Calendar;


import android.content.Context;
import android.os.Environment;
import android.text.Editable;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.EditText;
import android.widget.LinearLayout;



public class ClearableEditText extends LinearLayout
{
  private static final String TAG = "EditText";

  EditText editText;
  Button clearButton;
  Button hideKBButton;
  Button setButton;
  Button saveButton;
  Button loadButton;

  public ClearableEditText(Context context) {
    super(context);

    // Get a reference to the LayoutInflater Service
    String infService = Context.LAYOUT_INFLATER_SERVICE;
    LayoutInflater li = (LayoutInflater)getContext().getSystemService(infService);

    // Inflate the view from the layout resource
    li.inflate(R.layout.text_button_group_layout, this, true);

    // Get references to the child controls
   editText = (EditText)findViewById(R.id.editText);
   editText.setImeOptions(EditorInfo.IME_ACTION_SEARCH);

   clearButton = (Button)findViewById(R.id.clearButton);
   hideKBButton = (Button)findViewById(R.id.hidevkButton);
   setButton  = (Button)findViewById(R.id.setButton);
   saveButton  = (Button)findViewById(R.id.saveButton);
   loadButton  = (Button)findViewById(R.id.loadButton);

    // Hook up the functionality
   hookupButton(context);
  }


  //
  //
  //
  final String STORE_DIR = "Arc";
  final String STORE_FILENAME = "ArcEdit.txt";
  private void saveToFile(Editable strWrite){
        //open a file on the SD card under some useful name, and write out data
      FileWriter fw = null;
      File f = null;
      try {
          f = new File(Environment.getExternalStorageDirectory() + "/" +
                  STORE_DIR);
          if (f.mkdirs() == false) {
              Log.v(TAG, "Directory had not or alredy exist");
          }
          // EXPORT_FILENAME includes current date+time, for user benefit
          String fileName = String.format(STORE_FILENAME, Calendar.getInstance());
          f = new File(Environment.getExternalStorageDirectory() + "/" +
                  STORE_DIR + "/" + fileName);
          if (!f.createNewFile()) {
              f.delete();
              if (!f.createNewFile()) {
                  Log.v(TAG, "File cant will be replaced");
              }
          }

          fw = new FileWriter(f);
          fw.write(strWrite.toString());
      } catch (IOException e) {
          Log.v(TAG, "IOException" + e);
          return;
      } finally {
          if (fw != null) {
          try {
              fw.close();
          } catch (IOException e) {
              Log.v(TAG, "IOException" + e);
          }
          }
      }
  }


//
//
//
   private String LoadFromFile(){
           String strTxt = null;
        // first see if an SD card is even present; abort if not
        if (!Environment.MEDIA_MOUNTED.equals(Environment
                .getExternalStorageState())) {
            Log.v(TAG, "MEDIA_MOUNTED False");
            return null;
        }
        FileReader fr = null;
        try {
            // first, find the file to load
            File file = new File(Environment.getExternalStorageDirectory() + "/" + STORE_DIR + "/" + STORE_FILENAME);
            fr = new FileReader(file);

            BufferedReader reader = new BufferedReader(new FileReader(file));
            strTxt = reader.readLine();
            //while ((strTxt += reader.readLine()) != null);

        } catch (IOException e) {
             Log.v(TAG, "IOException" + e);
            return null;
        } finally {
            if (fr != null) {
                try {
                    fr.close();
                } catch (IOException e) {
                    Log.v(TAG, "IOException" + e);
                    return null;
                }
            }
        }
        return strTxt;
    }


  private void hookupButton(final Context context) {
      clearButton.setOnClickListener(new Button.OnClickListener() {
        public void onClick(View v) {
          editText.setText("");
        }
      });

      hideKBButton.setOnClickListener(new Button.OnClickListener() {
          public void onClick(View v) {
             InputMethodManager imm = (InputMethodManager)context.getSystemService(Context.INPUT_METHOD_SERVICE);
             imm.hideSoftInputFromWindow(editText.getWindowToken(), 0);
          }
      });

      setButton.setOnClickListener(new Button.OnClickListener() {
          public void onClick(View v) {
              if (editText.getTextSize() == 36.0f) {
                  //Small text
                    editText.setTextSize(10.0f);
                  }
                  else {
                  //Large text
                      editText.setTextSize(36.0f);
                  }

          }
     });

      saveButton.setOnClickListener(new Button.OnClickListener() {
          public void onClick(View v) {
      boolean mExternalStorageAvailable = false;
      boolean mExternalStorageWriteable = false;
      String state = Environment.getExternalStorageState();

      if (Environment.MEDIA_MOUNTED.equals(state)) {
          // We can read and write the media
          mExternalStorageAvailable = mExternalStorageWriteable = true;
          saveToFile(editText.getText());
      } else if (Environment.MEDIA_MOUNTED_READ_ONLY.equals(state)) {
          // We can only read the media
          mExternalStorageAvailable = true;
          mExternalStorageWriteable = false;
      } else {
          // Something else is wrong. It may be one of many other states, but all we need
          //  to know is we can neither read nor write
          mExternalStorageAvailable = mExternalStorageWriteable = false;
      }
          }
      });

      loadButton.setOnClickListener(new Button.OnClickListener() {
          public void onClick(View v) {
              String strTxt = null;
              strTxt = LoadFromFile();
              editText.setText(strTxt);
          }
      });
  }
}

